@@ -5,7 +5,7 @@ use warnings;
 
 use vars qw($VERSION); 
 # this module is used only for the VERSION line below and the perldocs
-$VERSION = '0.08';
+$VERSION = '0.10';
 
 1;
 
@@ -13,8 +13,7 @@ __END__
 
 =head1 NAME
 
-swished - a set of perl modules to provide a persistent swish-e daemon. 
-A reference implementation intended to be used with SWISH::API::Remote.
+swished - A set of perl modules to provide a persistent swish-e daemon; intended to be used with SWISH::API::Remote.
 
 =head1 SYNOPSIS
 
@@ -68,7 +67,7 @@ or you could test the CGI or Apache::Registry installation with command like:
 
 the format for the text you'll see is explained in the file PROTOCOL
 and is expected to be read by SWISH::API::Remote 
-(see L<http://joshr.com/src/SWISH-API-Remote/>)
+(see L<http://search.cpan.org/~joshr/SWISH-API-Remote/>)
 
 =head1 SEE ALSO
 
@@ -80,10 +79,24 @@ joshr, C<< <joshr> >>
 
 =head1 Copyright & License
 
-Copyright 2004 joshr, All Rights Reserved.
+Copyright 2004-2006 joshr, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
+# $Log: SWISHED.pm,v $
+# Revision 1.13  2006/07/06 18:00:52  joshr
+# bump to version 0.10, comment and documentation changes
+#
+# Revision 1.12  2006/06/17 17:29:02  joshr
+# version bump to 0.09p
+#
+# Revision 1.11  2006/06/17 17:09:26  joshr
+# version bump to 0.09n
+#
+# Revision 1.10  2006/06/04 16:59:30  joshr
+# version bump to 0.09m (l was skipped, it looks like a 1)
+#
+
